﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Ozeki.Media.MediaHandlers;

namespace DTMF_IVR_WinForm.Model
{
    /// <summary>
    /// IVR menu that play a wav file as an introduction.
    /// </summary>
    class IVRMenuFilePlayback : IVRMenuBase
    {
        /// <summary>
        /// wav file player object.
        /// </summary>
        private WaveStreamPlayback waveStreamPlayback;

        public IVRMenuFilePlayback(IVRMenuElement menu):base(menu)
        {}

        public override void StartIntroduction()
        {
            waveStreamPlayback = new WaveStreamPlayback(Introduction);
            waveStreamPlayback.Stopped += new EventHandler<EventArgs>(waveStreamPlayback_Stopped);
            OnIntroductionStarting(waveStreamPlayback);
            waveStreamPlayback.StartStreaming();
        }

        public override void StopIntroduction()
        {
            waveStreamPlayback.Stopped -= waveStreamPlayback_Stopped;
            waveStreamPlayback.StopStreaming();
            OnIntroductionStoped(waveStreamPlayback);
            waveStreamPlayback.Dispose();
            
        }

        public override void RestartIntroduction()
        {
            waveStreamPlayback.StartStreaming();
        }

        public override void CommandReceived(int signal)
        {
            waveStreamPlayback.Stopped -= waveStreamPlayback_Stopped;
            waveStreamPlayback.StopStreaming();
            switch (signal)
            {
                case 0:
                    OnIntroductionStoped(waveStreamPlayback);
                    OnStepIntoMenu(null);
                    waveStreamPlayback.Dispose();
                    return;
                case 10:
                    OnIntroductionStoped(waveStreamPlayback);
                    OnStepIntoMenu(Parent);
                    waveStreamPlayback.Dispose();
                    return;
            }
            foreach (var child in ChildMenus)
            {
                if (child.ActionKey == signal)
                {
                    OnIntroductionStoped(waveStreamPlayback);
                    waveStreamPlayback.Dispose();
                    OnStepIntoMenu(child);
                    return;
                }
            }
            //Wrong signal received so it restarts the playing.
            waveStreamPlayback.Stopped += waveStreamPlayback_Stopped;
            RestartIntroduction();
        }

        /// <summary>
        /// Indicates the introduction has finished.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void waveStreamPlayback_Stopped(object sender, EventArgs e)
        {
            OnIntroductionFinished();
        }
    }
}
