﻿using System;
using Ozeki.Media.MediaHandlers;

namespace DTMF_IVR_WinForm.Model
{
    /// <summary>
    /// IVR menu that reads introduction from text.
    /// </summary>
    class IVRMenuTextToSpeech : IVRMenuBase
    {
        /// <summary>
        /// text to speech reader.
        /// </summary>
        private TextToSpeech txtToSpeech;

        public IVRMenuTextToSpeech(IVRMenuElement menu): base(menu)
        {}

        public override void StartIntroduction()
        {
            txtToSpeech = new TextToSpeech(new Ozeki.VoIP.Media.AudioFormat(8000, 1, 16, 20));
            txtToSpeech.Stopped += new EventHandler<EventArgs>(txtToSpeech_Stopped);
            OnIntroductionStarting(txtToSpeech);
            txtToSpeech.AddText(Introduction);
            txtToSpeech.StartStreaming();
        }

        public override void StopIntroduction()
        {
            txtToSpeech.Stopped -= txtToSpeech_Stopped;
            txtToSpeech.StopStreaming();
            txtToSpeech.Dispose();
            OnIntroductionStoped(txtToSpeech);
        }

        public override void RestartIntroduction()
        {
            txtToSpeech.AddText(Introduction);
            txtToSpeech.StartStreaming();
        }

        public override void CommandReceived(int signal)
        {
            txtToSpeech.Stopped -= txtToSpeech_Stopped;
            txtToSpeech.StopStreaming();
            switch (signal)
            {
                case 0:
                    OnIntroductionStoped(txtToSpeech);
                    OnStepIntoMenu(null);
                    txtToSpeech.Dispose();
                    return;
                case 10:
                    OnIntroductionStoped(txtToSpeech);
                   OnStepIntoMenu(Parent);
                   txtToSpeech.Dispose();
                   return;
            }

            foreach (var child in ChildMenus)
            {
                if (child.ActionKey == signal)
                {
                    OnIntroductionStoped(txtToSpeech);
                    OnStepIntoMenu(child);
                    txtToSpeech.Dispose();
                    return;
                }
            }

            //Wrong signal received so it restarts the playing.
            txtToSpeech.Stopped += txtToSpeech_Stopped;
            RestartIntroduction();
        }


        void txtToSpeech_Stopped(object sender, EventArgs e)
        {
            OnIntroductionFinished();
        }

    }
}
